@@ -60,6 +60,15 @@ calc_pwr_pval_adj <- function(dist = "Chi2",# Distribution to base calculation f
   if(m < 1 | m != round(m)){
     stop("'m' must be a positive whole number.")
   }
+  if(varY1 <= 0){
+    stop("'varY1' must be positive.")
+  }
+  if(varY2 <= 0){
+    stop("'varY2' must be positive.")
+  }
+  if(alpha <= 0 | alpha >= 1){
+    stop("'alpha' must be between 0 and 1.")
+  }
 
   # Defining necessary parameters based on input values
   r_alt <- 1/(r + 1)
@@ -190,6 +199,15 @@ calc_K_pval_adj <- function(dist = "Chi2",# Distribution to base calculation fro
   if(m < 1 | m != round(m)){
     stop("'m' must be a positive whole number.")
   }
+  if(varY1 <= 0){
+    stop("'varY1' must be positive.")
+  }
+  if(varY2 <= 0){
+    stop("'varY2' must be positive.")
+  }
+  if(alpha <= 0 | alpha >= 1){
+    stop("'alpha' must be between 0 and 1.")
+  }
 
   if(dist == "Chi2"){ # Using Chi2
 
@@ -369,6 +387,15 @@ calc_m_pval_adj <- function(dist = "Chi2",# Distribution to base calculation fro
   if(K < 1 | K != round(K)){
     stop("'K' must be a positive whole number.")
   }
+  if(varY1 <= 0){
+    stop("'varY1' must be positive.")
+  }
+  if(varY2 <= 0){
+    stop("'varY2' must be positive.")
+  }
+  if(alpha <= 0 | alpha >= 1){
+    stop("'alpha' must be between 0 and 1.")
+  }
 
   if(dist == "Chi2"){ # Using Chi2
 
